@@ -777,7 +777,7 @@ func NewClusterConfig() *ClusterConfig {
 		KubernetesNetworkConfig: &KubernetesNetworkConfig{
 			IPFamily: DefaultIPFamily,
 		},
-		VPC: NewClusterVPC(),
+		VPC: NewClusterVPC(false),
 		CloudWatch: &ClusterCloudWatch{
 			ClusterLogging: &ClusterCloudWatchLogging{},
 		},
@@ -788,15 +788,20 @@ func NewClusterConfig() *ClusterConfig {
 }
 
 // NewClusterVPC creates new VPC config for a cluster
-func NewClusterVPC() *ClusterVPC {
+func NewClusterVPC(ipv6Enabled bool) *ClusterVPC {
 	cidr := DefaultCIDR()
 
+	var nat *ClusterNAT
+	if !ipv6Enabled {
+		nat = DefaultClusterNAT()
+	}
+
 	return &ClusterVPC{
 		Network: Network{
 			CIDR: &cidr,
 		},
 		ManageSharedNodeSecurityGroupRules: Enabled(),
-		NAT:                                DefaultClusterNAT(),
+		NAT:                                nat,
 		AutoAllocateIPv6:                   Disabled(),
 		ClusterEndpoints:                   &ClusterEndpoints{},
 	}
@@ -819,6 +824,10 @@ func (c *ClusterConfig) AppendAvailabilityZone(newAZ string) {
 	c.AvailabilityZones = append(c.AvailabilityZones, newAZ)
 }
 
+func (c *ClusterConfig) IPv6Enabled() bool {
+	return c.KubernetesNetworkConfig != nil && c.KubernetesNetworkConfig.IPv6Enabled()
+}
+
 // SetClusterStatus populates ClusterStatus using *eks.Cluster.
 func (c *ClusterConfig) SetClusterStatus(cluster *eks.Cluster) error {
 	if networkConfig := cluster.KubernetesNetworkConfig; networkConfig != nil && networkConfig.ServiceIpv4Cidr != nil {
@@ -1209,6 +1218,29 @@ type NodePool interface {
 	NGTaints() []NodeGroupTaint
 }
 
+// VolumeMapping Additional Volume Configurations
+type VolumeMapping struct {
+	// +optional
+	// VolumeSize gigabytes
+	// Defaults to `80`
+	VolumeSize *int `json:"volumeSize,omitempty"`
+	// Valid variants are `VolumeType` constants
+	// +optional
+	VolumeType *string `json:"volumeType,omitempty"`
+	// +optional
+	VolumeName *string `json:"volumeName,omitempty"`
+	// +optional
+	VolumeEncrypted *bool `json:"volumeEncrypted,omitempty"`
+	// +optional
+	VolumeKmsKeyID *string `json:"volumeKmsKeyID,omitempty"`
+	// +optional
+	VolumeIOPS *int `json:"volumeIOPS,omitempty"`
+	// +optional
+	VolumeThroughput *int `json:"volumeThroughput,omitempty"`
+	// +optional
+	SnapshotID *string `json:"snapshotID,omitempty"`
+}
+
 // NodeGroupBase represents the base nodegroup config for self-managed and managed nodegroups
 type NodeGroupBase struct {
 	// +required
@@ -1290,6 +1322,10 @@ type NodeGroupBase struct {
 	// +optional
 	VolumeThroughput *int `json:"volumeThroughput,omitempty"`
 
+	// Additional Volume Configurations
+	// +optional
+	AdditionalVolumes []*VolumeMapping `json:"additionalVolumes,omitempty"`
+
 	// PreBootstrapCommands are executed before bootstrapping instances to the
 	// cluster
 	// +optional
