@@ -7,6 +7,7 @@ import (
 	"reflect"
 
 	"github.com/pkg/errors"
+
 	"github.com/weaveworks/eksctl/pkg/utils/ipnet"
 )
 
@@ -137,6 +138,10 @@ type (
 		// private subnets or any ad-hoc subnets
 		// +optional
 		ExtraCIDRs []string `json:"extraCIDRs,omitempty"`
+		// for additional IPv6 CIDR associations, e.g. a CIDR for
+		// private subnets or any ad-hoc subnets
+		// +optional
+		ExtraIPv6CIDRs []string `json:"extraIPv6CIDRs,omitempty"`
 		// for pre-defined shared node SG
 		SharedNodeSecurityGroup string `json:"sharedNodeSecurityGroup,omitempty"`
 		// Automatically add security group rules to and from the default
@@ -182,6 +187,10 @@ type (
 		ID string `json:"id,omitempty"`
 		// +optional
 		CIDR *ipnet.IPNet `json:"cidr,omitempty"`
+		// +optional
+		IPv6Cidr string `json:"ipv6Cidr,omitempty"`
+		// +optional
+		IPv6Pool string `json:"ipv6Pool,omitempty"`
 	}
 	// ClusterNAT NAT config
 	ClusterNAT struct {
