@@ -53,7 +53,7 @@ func NewNodeGroupResourceSet(ec2API ec2iface.EC2API, iamAPI iamiface.IAMAPI, spe
 // AddAllResources adds all the information about the nodegroup to the resource set
 func (n *NodeGroupResourceSet) AddAllResources() error {
 
-	if n.clusterSpec.KubernetesNetworkConfig != nil && n.clusterSpec.KubernetesNetworkConfig.IPv6Enabled() {
+	if n.clusterSpec.IPv6Enabled() {
 		return errors.New("unmanaged nodegroups are not supported with IPv6 clusters")
 	}
 
