@@ -1042,6 +1042,57 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 						Expect(mapping.Ebs["Encrypted"]).To(Equal(true))
 					})
 				})
+
+				Context("ng.AdditionalVolumes is set", func() {
+					BeforeEach(func() {
+						ng.AdditionalVolumes = []*api.VolumeMapping{
+							{
+								VolumeSize:      aws.Int(20),
+								VolumeType:      aws.String(api.NodeVolumeTypeGP3),
+								VolumeName:      aws.String("/foo/bar-add-1"),
+								VolumeEncrypted: aws.Bool(true),
+								SnapshotID:      aws.String("snapshot-id"),
+							},
+						}
+					})
+					It("adds the additional volumes to the template", func() {
+						Expect(ngTemplate.Resources["NodeGroupLaunchTemplate"].Properties.LaunchTemplateData.BlockDeviceMappings).To(HaveLen(2))
+						mapping := ngTemplate.Resources["NodeGroupLaunchTemplate"].Properties.LaunchTemplateData.BlockDeviceMappings[1]
+						Expect(mapping.DeviceName).To(Equal("/foo/bar-add-1"))
+						Expect(mapping.Ebs["Encrypted"]).To(Equal(true))
+						Expect(mapping.Ebs["VolumeSize"]).To(Equal(float64(20)))
+						Expect(mapping.Ebs["VolumeType"]).To(Equal(api.NodeVolumeTypeGP3))
+						Expect(mapping.Ebs["SnapshotId"]).To(Equal("snapshot-id"))
+					})
+					When("VolumeSize is empty", func() {
+						BeforeEach(func() {
+							ng.AdditionalVolumes = []*api.VolumeMapping{
+								{
+									VolumeType:      aws.String(api.NodeVolumeTypeGP3),
+									VolumeName:      aws.String("/foo/bar-add-1"),
+									VolumeEncrypted: aws.Bool(true),
+								},
+							}
+						})
+						It("does not add the new volume", func() {
+							Expect(ngTemplate.Resources["NodeGroupLaunchTemplate"].Properties.LaunchTemplateData.BlockDeviceMappings).To(HaveLen(1))
+						})
+					})
+					When("VolumeName is empty", func() {
+						BeforeEach(func() {
+							ng.AdditionalVolumes = []*api.VolumeMapping{
+								{
+									VolumeSize:      aws.Int(20),
+									VolumeType:      aws.String(api.NodeVolumeTypeGP3),
+									VolumeEncrypted: aws.Bool(true),
+								},
+							}
+						})
+						It("does not add the new volume", func() {
+							Expect(ngTemplate.Resources["NodeGroupLaunchTemplate"].Properties.LaunchTemplateData.BlockDeviceMappings).To(HaveLen(1))
+						})
+					})
+				})
 			})
 
 			Context("ng.SecurityGroups.AttachIDs are set", func() {
