@@ -38,7 +38,7 @@ type NodeGroupSummary struct {
 	DesiredCapacity      int
 	InstanceType         string
 	ImageID              string
-	CreationTime         *time.Time
+	CreationTime         time.Time
 	NodeInstanceRoleARN  string
 	AutoScalingGroupName string
 	Version              string
@@ -85,7 +85,7 @@ func (c *StackCollection) createManagedNodeGroupTask(errorCh chan error, ng *api
 	if err != nil {
 		return err
 	}
-	if cluster == nil && c.spec.KubernetesNetworkConfig != nil && c.spec.KubernetesNetworkConfig.IPv6Enabled() {
+	if cluster == nil && c.spec.IPv6Enabled() {
 		return errors.New("managed nodegroups cannot be created on IPv6 unowned clusters")
 	}
 	logger.Info("building managed nodegroup stack %q", name)
@@ -193,36 +193,38 @@ func (c *StackCollection) GetUnmanagedNodeGroupSummaries(name string) ([]*NodeGr
 			return nil, err
 		}
 
-		if nodeGroupType == api.NodeGroupTypeUnmanaged {
-			ngPaths, err := getNodeGroupPaths(s.Tags)
-			if err != nil {
-				return nil, err
-			}
+		if nodeGroupType != api.NodeGroupTypeUnmanaged {
+			continue
+		}
 
-			summary, err := c.mapStackToNodeGroupSummary(s, ngPaths)
+		ngPaths, err := getNodeGroupPaths(s.Tags)
+		if err != nil {
+			return nil, err
+		}
 
-			if err != nil {
-				return nil, errors.Wrap(err, "mapping stack to nodegroup summary")
-			}
+		summary, err := c.mapStackToNodeGroupSummary(s, ngPaths)
 
-			asgName, err := c.getUnmanagedNodeGroupAutoScalingGroupName(s)
-			if err != nil {
-				return nil, errors.Wrap(err, "getting autoscalinggroupname")
-			}
+		if err != nil {
+			return nil, errors.Wrap(err, "mapping stack to nodegroup summary")
+		}
 
-			summary.AutoScalingGroupName = asgName
+		asgName, err := c.getUnmanagedNodeGroupAutoScalingGroupName(s)
+		if err != nil {
+			return nil, errors.Wrap(err, "getting autoscalinggroupname")
+		}
 
-			scalingGroup, err := c.GetAutoScalingGroupDesiredCapacity(asgName)
-			if err != nil {
-				return nil, errors.Wrap(err, "getting autoscalinggroup desired capacity")
-			}
-			summary.DesiredCapacity = int(*scalingGroup.DesiredCapacity)
-			summary.MinSize = int(*scalingGroup.MinSize)
-			summary.MaxSize = int(*scalingGroup.MaxSize)
+		summary.AutoScalingGroupName = asgName
 
-			if name == "" || summary.Name == name {
-				summaries = append(summaries, summary)
-			}
+		scalingGroup, err := c.GetAutoScalingGroupDesiredCapacity(asgName)
+		if err != nil {
+			return nil, errors.Wrap(err, "getting autoscalinggroup desired capacity")
+		}
+		summary.DesiredCapacity = int(*scalingGroup.DesiredCapacity)
+		summary.MinSize = int(*scalingGroup.MinSize)
+		summary.MaxSize = int(*scalingGroup.MaxSize)
+
+		if name == "" || summary.Name == name {
+			summaries = append(summaries, summary)
 		}
 	}
 
@@ -255,7 +257,7 @@ func (c *StackCollection) GetAutoScalingGroupName(s *Stack) (string, error) {
 	}
 }
 
-// GetNodeGroupAutoScalingGroupName return the unmanaged nodegroup's AutoScalingGroupName
+// GetNodeGroupAutoScalingGroupName returns the unmanaged nodegroup's AutoScalingGroupName
 func (c *StackCollection) getUnmanagedNodeGroupAutoScalingGroupName(s *Stack) (string, error) {
 	input := &cfn.DescribeStackResourceInput{
 		StackName:         s.StackName,
@@ -269,7 +271,7 @@ func (c *StackCollection) getUnmanagedNodeGroupAutoScalingGroupName(s *Stack) (s
 	return *res.StackResourceDetail.PhysicalResourceId, nil
 }
 
-// GetManagedNodeGroupAutoScalingGroupName returns the managed nodegroup's AutoScalingGroupName
+// GetManagedNodeGroupAutoScalingGroupName returns the managed nodegroup's AutoScalingGroup names
 func (c *StackCollection) getManagedNodeGroupAutoScalingGroupName(s *Stack) (string, error) {
 	input := &eks.DescribeNodegroupInput{
 		ClusterName:   aws.String(getClusterNameTag(s)),
@@ -282,7 +284,7 @@ func (c *StackCollection) getManagedNodeGroupAutoScalingGroupName(s *Stack) (str
 		return "", nil
 	}
 
-	asgs := []string{}
+	var asgs []string
 
 	if res.Nodegroup.Resources != nil {
 		for _, v := range res.Nodegroup.Resources.AutoScalingGroups {
@@ -423,7 +425,7 @@ func (c *StackCollection) mapStackToNodeGroupSummary(stack *Stack, ngPaths *node
 		DesiredCapacity: int(gjson.Get(template, ngPaths.DesiredCapacity).Int()),
 		InstanceType:    gjson.Get(template, ngPaths.InstanceType).String(),
 		ImageID:         gjson.Get(template, imageIDPath).String(),
-		CreationTime:    stack.CreationTime,
+		CreationTime:    *stack.CreationTime,
 	}
 
 	nodeGroupType, err := GetNodeGroupType(stack.Tags)
